summaryrefslogtreecommitdiff
path: root/lib
diff options
context:
space:
mode:
authorNicholas Clark <nick@ccl4.org>2003-12-27 18:12:33 +0000
committerNicholas Clark <nick@ccl4.org>2003-12-27 18:12:33 +0000
commitaaa799f9f94038e03b6fe1069e18029f5c7fdb32 (patch)
treee4a1b9ad89f94bcc78f78ecca54944c3c1b8961e /lib
parent4fdb5a70f63a1d6604e29575f02327446e68127f (diff)
downloadperl-aaa799f9f94038e03b6fe1069e18029f5c7fdb32.tar.gz
Assimilate PodParser-1.26
p4raw-id: //depot/perl@21975
Diffstat (limited to 'lib')
-rw-r--r--lib/Pod/Checker.pm4
-rw-r--r--lib/Pod/Find.pm6
-rw-r--r--lib/Pod/InputObjects.pm2
-rw-r--r--lib/Pod/ParseUtils.pm4
-rw-r--r--lib/Pod/Parser.pm4
-rw-r--r--lib/Pod/PlainText.pm11
-rw-r--r--lib/Pod/Select.pm2
-rw-r--r--lib/Pod/Usage.pm2
8 files changed, 27 insertions, 8 deletions
diff --git a/lib/Pod/Checker.pm b/lib/Pod/Checker.pm
index 824178f61c..78e27c4eb4 100644
--- a/lib/Pod/Checker.pm
+++ b/lib/Pod/Checker.pm
@@ -1254,8 +1254,10 @@ __END__
=head1 AUTHOR
+Please report bugs using L<http://rt.cpan.org>.
+
Brad Appleton E<lt>bradapp@enteract.comE<gt> (initial version),
-Marek Rouchal E<lt>marek@saftsack.fs.uni-bayreuth.deE<gt>
+Marek Rouchal E<lt>marekr@cpan.orgE<gt>
Based on code for B<Pod::Text::pod2text()> written by
Tom Christiansen E<lt>tchrist@mox.perl.comE<gt>
diff --git a/lib/Pod/InputObjects.pm b/lib/Pod/InputObjects.pm
index 9cd347b969..d895b104a4 100644
--- a/lib/Pod/InputObjects.pm
+++ b/lib/Pod/InputObjects.pm
@@ -932,6 +932,8 @@ See L<Pod::Parser>, L<Pod::Select>
=head1 AUTHOR
+Please report bugs using L<http://rt.cpan.org>.
+
Brad Appleton E<lt>bradapp@enteract.comE<gt>
=cut
diff --git a/lib/Pod/ParseUtils.pm b/lib/Pod/ParseUtils.pm
index 18e9626e0e..cb784a1a9d 100644
--- a/lib/Pod/ParseUtils.pm
+++ b/lib/Pod/ParseUtils.pm
@@ -836,7 +836,9 @@ sub idx {
=head1 AUTHOR
-Marek Rouchal E<lt>marek@saftsack.fs.uni-bayreuth.deE<gt>, borrowing
+Please report bugs using L<http://rt.cpan.org>.
+
+Marek Rouchal E<lt>marekr@cpan.orgE<gt>, borrowing
a lot of things from L<pod2man> and L<pod2roff> as well as other POD
processing tools by Tom Christiansen, Brad Appleton and Russ Allbery.
diff --git a/lib/Pod/Parser.pm b/lib/Pod/Parser.pm
index 456b515b9a..d12e01624a 100644
--- a/lib/Pod/Parser.pm
+++ b/lib/Pod/Parser.pm
@@ -10,7 +10,7 @@
package Pod::Parser;
use vars qw($VERSION);
-$VERSION = 1.13; ## Current version of this package
+$VERSION = 1.14; ## Current version of this package
require 5.005; ## requires this Perl version or later
#############################################################################
@@ -1764,6 +1764,8 @@ causing any namespace clashes due to multiple inheritance.
=head1 AUTHOR
+Please report bugs using L<http://rt.cpan.org>.
+
Brad Appleton E<lt>bradapp@enteract.comE<gt>
Based on code for B<Pod::Text> written by
diff --git a/lib/Pod/PlainText.pm b/lib/Pod/PlainText.pm
index 4250ebb5fe..3f5ce90d2b 100644
--- a/lib/Pod/PlainText.pm
+++ b/lib/Pod/PlainText.pm
@@ -29,7 +29,7 @@ use vars qw(@ISA %ESCAPES $VERSION);
# by Pod::Usage.
@ISA = qw(Pod::Select);
-($VERSION = (split (' ', q$Revision: 2.1 $ ))[1]) =~ s/\.(\d)$/.0$1/;
+$VERSION = '2.02';
############################################################################
@@ -396,7 +396,10 @@ sub seq_l {
# something looking like L<manpage(section)>. The latter is an
# enhancement over the original Pod::Text.
my ($manpage, $section) = ('', $_);
- if (/^"\s*(.*?)\s*"$/) {
+ if (/^(?:https?|ftp|news):/) {
+ # a URL
+ return $_;
+ } elsif (/^"\s*(.*?)\s*"$/) {
$section = '"' . $1 . '"';
} elsif (m/^[-:.\w]+(?:\(\S+\))?$/) {
($manpage, $section) = ($_, '');
@@ -404,8 +407,8 @@ sub seq_l {
($manpage, $section) = split (/\s*\/\s*/, $_, 2);
}
- # Now build the actual output text.
my $text = '';
+ # Now build the actual output text.
if (!length $section) {
$text = "the $manpage manpage" if length $manpage;
} elsif ($section =~ /^[:\w]+(?:\(\))?/) {
@@ -692,6 +695,8 @@ pod2text(1)
=head1 AUTHOR
+Please report bugs using L<http://rt.cpan.org>.
+
Russ Allbery E<lt>rra@stanford.eduE<gt>, based I<very> heavily on the
original Pod::Text by Tom Christiansen E<lt>tchrist@mox.perl.comE<gt> and
its conversion to Pod::Parser by Brad Appleton
diff --git a/lib/Pod/Select.pm b/lib/Pod/Select.pm
index 8310ea6c7c..8b98544338 100644
--- a/lib/Pod/Select.pm
+++ b/lib/Pod/Select.pm
@@ -740,6 +740,8 @@ L<Pod::Parser>
=head1 AUTHOR
+Please report bugs using L<http://rt.cpan.org>.
+
Brad Appleton E<lt>bradapp@enteract.comE<gt>
Based on code for B<pod2text> written by
diff --git a/lib/Pod/Usage.pm b/lib/Pod/Usage.pm
index 63c7007bc5..f363b3a4ce 100644
--- a/lib/Pod/Usage.pm
+++ b/lib/Pod/Usage.pm
@@ -381,6 +381,8 @@ similar to the following:
=head1 AUTHOR
+Please report bugs using L<http://rt.cpan.org>.
+
Brad Appleton E<lt>bradapp@enteract.comE<gt>
Based on code for B<Pod::Text::pod2text()> written by
diff --git a/lib/Pod/Find.pm b/lib/Pod/Find.pm
index e18d976ffb..21af123065 100644
--- a/lib/Pod/Find.pm
+++ b/lib/Pod/Find.pm
@@ -1,7 +1,7 @@
#############################################################################
# Pod/Find.pm -- finds files containing POD documentation
#
# Author: Marek Rouchal <marek@saftsack.fs.uni-bayreuth.de>
#
# Copyright (C) 1999-2000 by Marek Rouchal (and borrowing code
# from Nick Ing-Simmon's PodToHtml). All rights reserved.
@@ -498,7 +498,9 @@ sub contains_pod {
=head1 AUTHOR
-Marek Rouchal E<lt>marek@saftsack.fs.uni-bayreuth.deE<gt>,
+Please report bugs using L<http://rt.cpan.org>.
+
+Marek Rouchal E<lt>marekr@cpan.orgE<gt>,
heavily borrowing code from Nick Ing-Simmons' PodToHtml.
Tim Jenness E<lt>t.jenness@jach.hawaii.eduE<gt> provided
@@ -1,7 +1,7 @@
# Pod/Find.pm -- finds files containing POD documentation
#
-# Author: Marek Rouchal <marek@saftsack.fs.uni-bayreuth.de>
+# Author: Marek Rouchal <marekr@cpan.org>
#
# Copyright (C) 1999-2000 by Marek Rouchal (and borrowing code